@@ -190,7 +190,11 @@ class TestNodeSetIndex:
 
         ns.create_index(graph)
 
-        result = run_query_return_results(graph, "CALL db.indexes()")
+        # TODO keep until 4.2 is not supported anymore
+        try:
+            result = run_query_return_results(graph, "SHOW INDEXES YIELD *")
+        except:
+            result = run_query_return_results(graph, "CALL db.indexes()")
 
         for row in result:
             # the result of the db.indexes() procedure is different for Neo4j 3.5 and 4
@@ -210,7 +214,11 @@ class TestNodeSetIndex:
 
         ns.create_index(graph)
 
-        result = run_query_return_results(graph, "CALL db.indexes()")
+        # TODO keep until 4.2 is not supported anymore
+        try:
+            result = run_query_return_results(graph, "SHOW INDEXES YIELD *")
+        except:
+            result = run_query_return_results(graph, "CALL db.indexes()")
 
         for row in result:
             # the result of the db.indexes() procedure is different for Neo4j 3.5 and 4
